==> dde-daemon_6.0.44.tar.xz: BUILD/misc/ts/org.deepin.dde.fprintd.policy/policy_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Se requiere autenticación para añadir contraseña de huella dactilar</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Añadir contraseña de huella dactilar</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Se requiere autenticación para borrar contraseñas de huellas dactilares</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Borrar contraseñas de huellas dactilares</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Se requiere autenticación para renombrar la contraseña huella dactilar</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Renombrar contraseña de huella dactilar</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Se requiere contraseña para realizar esta acción</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Administrar contraseñas de huellas digitales</translation>
		</message>
	</context>
</TS>

==> dde-daemon_6.1.27.tar.xz: BUILD/misc/ts/org.deepin.dde.fprintd.policy/policy_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Se requiere autenticación para añadir contraseña de huella dactilar</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Añadir contraseña de huella dactilar</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Se requiere autenticación para borrar contraseñas de huellas dactilares.</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Borrar contraseñas de huellas dactilares</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Se requiere autenticación para renombrar la contraseña huella dactilar</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Renombrar contraseña de huella dactilar</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Se requiere contraseña para realizar esta acción</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Administrar contraseñas de huellas digitales</translation>
		</message>
	</context>
</TS>
